/**
 * Configure oidc-client library.
 * 
 */

import Oidc from 'oidc-client';

Oidc.Log.logger = console;
Oidc.Log.level = (process.env.NODE_ENV === 'production') ? Oidc.Log.ERROR : Oidc.Log.DEBUG;

// OIDC configuration
let oidcProviderDomain = 'https://basebox-test-1.eu.auth0.com';
let clientId = '5wl8hQV1thh07rScSoJ3aN56ETuXWprg';
let scopes = "openid profile email"

let instance;

// OIDC Client
export const getOidcClient = () => {
  if (instance) {
    return instance;
  }

  instance = new Oidc.UserManager({
    userStore: new Oidc.WebStorageStateStore(),
    authority: oidcProviderDomain,
    client_id: clientId,
    redirect_uri: window.location.origin + '/callback',
    response_type: 'code',
    scope: scopes,
    post_logout_redirect_uri: window.location.origin + '/home?action=logout',
    accessTokenExpiringNotificationTime: 10,
    automaticSilentRenew: false,
    filterProtocolClaims: false,
    loadUserInfo: true,
    includeIdTokenInSilentRenew: false
  });

  instance.events.addAccessTokenExpiring(function() {
    // eslint-disable-next-line no-console
    console.log('access token expiring')
  })
  
  instance.events.addAccessTokenExpired(function() {
    // eslint-disable-next-line no-console
    console.log('access token expired')
  })
  
  instance.events.addSilentRenewError(function(err) {
    // eslint-disable-next-line no-console
    console.error('silent renew error', err)
  })
  
  instance.events.addUserLoaded(function(user) {
    // eslint-disable-next-line no-console
    console.log('user loaded', user)
  })
  
  instance.events.addUserSignedIn(function(user) {
    // eslint-disable-next-line no-console
    console.log('user signed in', user)
  })
  
  instance.events.addUserUnloaded(function() {
    // eslint-disable-next-line no-console
    console.log('user unloaded')
  })
  
  instance.events.addUserSignedOut(function() {
    // eslint-disable-next-line no-console
    console.log('user signed out')
  })
  
  instance.events.addUserSessionChanged(function() {
    // eslint-disable-next-line no-console
    console.log('user session changed')
  })

  return instance;
}
